@@ -43,88 +43,89 @@
 #define ICON_PADDING_RIGHT_LEN (sizeof ICON_PADDING_RIGHT - 1)
 
 /* ARROWS */
-#define ICON_ARROW_UP      ICON_STR(MD_ARROW_UPWARD, "\uf55c", "⬆")
-#define ICON_ARROW_FORWARD ICON_STR(MD_ARROW_FORWARD, "\uf553", "➡")
-#define ICON_ARROW_DOWN    ICON_STR(MD_ARROW_DOWNWARD, "\uf544", "⬇")
+#define ICON_ARROW_UP      ICON_STR(MD_ARROW_UPWARD, "󰁝", "⬆")
+#define ICON_ARROW_FORWARD ICON_STR(MD_ARROW_FORWARD, "󰁔", "➡")
+#define ICON_ARROW_DOWN    ICON_STR(MD_ARROW_DOWNWARD, "󰁅", "⬇")
 
 /* GENERIC */
-#define ICON_DIRECTORY     ICON_STR(FA_FOLDER, "\ue5ff", "📂")
-#define ICON_FILE          ICON_STR(FA_FILE, "\uf713", "📃")
-#define ICON_EXEC          ICON_STR(FA_COG, "\uf144", "⚙️ ")
+#define ICON_DIRECTORY     ICON_STR(FA_FOLDER, "", "📂")
+#define ICON_FILE          ICON_STR(FA_FILE, "󰈔", "📃")
+#define ICON_EXEC          ICON_STR(FA_COG, "", "⚙️ ")
 
 /* Top level and common icons */
-#define ICON_ARCHIVE       ICON_STR(FA_FILE_ARCHIVE_O, "\uf53b", "📦")
-#define ICON_BRIEFCASE     ICON_STR(FA_BRIEFCASE, "\uf5d5", "💼")
-#define ICON_C             ICON_STR(MFIZZ_C, "\ue61e", "🇨 ")
-#define ICON_CHANGELOG     ICON_STR(FA_HISTORY, "\uf7d9", "🔺")
-#define ICON_CHESS         ICON_STR("", "\uf639", "")
-#define ICON_CLOJURE       ICON_STR(MFIZZ_CLOJURE, "\ue76a", "")
-#define ICON_CONFIGURE     ICON_STR(FILE_CONFIG, "\uf423", "🔧")
-#define ICON_CPLUSPLUS     ICON_STR(MFIZZ_CPLUSPLUS, "\ue61d", ICON_C)
-#define ICON_DATABASE      ICON_STR(MFIZZ_DATABASE_ALT2, "\uf6b7", "🗃️ ")
-#define ICON_DESKTOP       ICON_STR(FA_DESKTOP, "\ufcbe", "🖥️ ")
-#define ICON_DOCUMENT      ICON_STR(FA_FILE_TEXT_O, "\uf718", "🗒 ")
-#define ICON_DOWNLOADS     ICON_STR(FA_DOWNLOAD, "\uf5d7", "📥")
-#define ICON_ELIXIR        ICON_STR(MFIZZ_ELIXIR, "\ue62d", "💧")
-#define ICON_ENCRYPT       ICON_STR("", "\uf805", "🔒")
-#define ICON_FSHARP        ICON_STR(DEV_FSHARP, "\ue7a7", "")
-#define ICON_FONT          ICON_STR(FILE_FONT, "\uf031", "")
-#define ICON_GIT           ICON_STR(FA_GIT, "\ue5fb", "🌱")
-#define ICON_HASKELL       ICON_STR("", "\ue777", "")
-#define ICON_HTML          ICON_STR(FA_FILE_CODE_O, "\uf72d", "")
-#define ICON_JAVA          ICON_STR(MFIZZ_JAVA, "\ue738", "☕")
-#define ICON_JAVASCRIPT    ICON_STR(FA_FILE_CODE_O, "\uf81d", "")
-#define ICON_LICENSE       ICON_STR(FA_COPYRIGHT, "\uf718", "⚖️ ")
-#define ICON_LINUX         ICON_STR(FA_LINUX, "\uf83c", "🐧")
-#define ICON_MAKEFILE      ICON_STR(FILE_CMAKE, "\uf68c", "🛠 ")
-#define ICON_MANUAL        ICON_STR(FILE_MANPAGE, "\uf5bd", "❓")
-#define ICON_MS_EXCEL      ICON_STR(FILE_EXCEL, "\uf71a", ICON_WORDDOC)
-#define ICON_MUSIC         ICON_STR(FA_MUSIC, "\uf832", "🎧")
-#define ICON_MUSICFILE     ICON_STR(FA_FILE_AUDIO_O, "\uf886", ICON_MUSIC)
-#define ICON_OPTICALDISK   ICON_STR(LINEA_MUSIC_CD, "\ue271", "💿")
-#define ICON_PDF           ICON_STR(FA_FILE_PDF_O, "\uf724", "📕")
-#define ICON_PHOTOSHOP     ICON_STR(DEV_PHOTOSHOP, "\ue7b8", ICON_PICTUREFILE)
-#define ICON_PICTUREFILE   ICON_STR(FA_FILE_IMAGE_O, "\uf71e", ICON_PICTURES)
-#define ICON_PICTURES      ICON_STR(MD_CAMERA_ALT, "\uf753", "🎨")
-#define ICON_PLAYLIST      ICON_STR(ICON_MUSICFILE, "\uf831", "")
-#define ICON_POWERPOINT    ICON_STR(FILE_POWERPOINT, "\uf726", "📊")
-#define ICON_PUBLIC        ICON_STR(FA_INBOX, "\ue5ff", "👀")
-#define ICON_PYTHON        ICON_STR(MFIZZ_PYTHON, "\ue235", "🐍")
-#define ICON_REACT         ICON_STR(FILE_JSX, "\ue625", ICON_JAVASCRIPT)
-#define ICON_RUBY          ICON_STR(MFIZZ_RUBY, "\ue23e", "💎")
-#define ICON_RUST          ICON_STR(DEV_RUST, "\ue7a8", "")
-#define ICON_SASS          ICON_STR("", "\ue603", "")
-#define ICON_SCRIPT        ICON_STR(MFIZZ_SCRIPT, "\ue795", "📜")
-#define ICON_SUBTITLE      ICON_STR(FA_COMMENTS_O, "\uf679", "💬")
-#define ICON_TEMPLATES     ICON_STR(FA_PAPERCLIP, "\ufac6", "📎")
-#define ICON_TEX           ICON_STR(FILE_TEX, "\ufb68", ICON_DOCUMENT)
-#define ICON_VIDEOFILE     ICON_STR(FA_FILE_MOVIE_O, "\uf72a", ICON_VIDEOS)
-#define ICON_VIDEOS        ICON_STR(FA_FILM, "\uf72f", "🎞 ")
-#define ICON_VIM           ICON_STR(DEV_VIM, "\ue62b", "")
-#define ICON_WORDDOC       ICON_STR(FILE_WORD, "\uf72b", "📘")
+#define ICON_ARCHIVE       ICON_STR(FA_FILE_ARCHIVE_O, "󰀼", "📦")
+#define ICON_BRIEFCASE     ICON_STR(FA_BRIEFCASE, "󰃖", "💼")
+#define ICON_C             ICON_STR(MFIZZ_C, "", "🇨 ")
+#define ICON_CHANGELOG     ICON_STR(FA_HISTORY, "󰋚", "🔺")
+#define ICON_CHESS         ICON_STR("", "󰄺", "")
+#define ICON_CLOJURE       ICON_STR(MFIZZ_CLOJURE, "", "")
+#define ICON_CONFIGURE     ICON_STR(FILE_CONFIG, "", "🔧")
+#define ICON_CPLUSPLUS     ICON_STR(MFIZZ_CPLUSPLUS, "", ICON_C)
+#define ICON_DATABASE      ICON_STR(MFIZZ_DATABASE_ALT2, "󰆼", "🗃️ ")
+#define ICON_DESKTOP       ICON_STR(FA_DESKTOP, "󰟀", "🖥️ ")
+#define ICON_DJVU          ICON_STR(FA_PAPERCLIP, "", "📎")
+#define ICON_DOCUMENT      ICON_STR(FA_FILE_TEXT_O, "󰈙", "🗒 ")
+#define ICON_DOWNLOADS     ICON_STR(FA_DOWNLOAD, "󰃘", "📥")
+#define ICON_ELIXIR        ICON_STR(MFIZZ_ELIXIR, "", "💧")
+#define ICON_ENCRYPT       ICON_STR("", "󰌆", "🔒")
+#define ICON_FSHARP        ICON_STR(DEV_FSHARP, "", "")
+#define ICON_FONT          ICON_STR(FILE_FONT, "", "")
+#define ICON_GIT           ICON_STR(FA_GIT, "", "🌱")
+#define ICON_HASKELL       ICON_STR("", "", "")
+#define ICON_HTML          ICON_STR(FA_FILE_CODE_O, "󰌝", "")
+#define ICON_JAVA          ICON_STR(MFIZZ_JAVA, "", "☕")
+#define ICON_JAVASCRIPT    ICON_STR(FA_FILE_CODE_O, "󰌞", "")
+#define ICON_LICENSE       ICON_STR(FA_COPYRIGHT, "󰈙", "⚖️ ")
+#define ICON_LINUX         ICON_STR(FA_LINUX, "󰌽", "🐧")
+#define ICON_MAKEFILE      ICON_STR(FILE_CMAKE, "󰆍", "🛠 ")
+#define ICON_MANUAL        ICON_STR(FILE_MANPAGE, "󱓷", "❓")
+#define ICON_MS_EXCEL      ICON_STR(FILE_EXCEL, "󰈛", ICON_WORDDOC)
+#define ICON_MUSIC         ICON_STR(FA_MUSIC, "󱍙", "🎧")
+#define ICON_MUSICFILE     ICON_STR(FA_FILE_AUDIO_O, "󰎈", ICON_MUSIC)
+#define ICON_OPTICALDISK   ICON_STR(LINEA_MUSIC_CD, "", "💿")
+#define ICON_PDF           ICON_STR(FA_FILE_PDF_O, "󰈦", "📕")
+#define ICON_PHOTOSHOP     ICON_STR(DEV_PHOTOSHOP, "", ICON_PICTUREFILE)
+#define ICON_PICTUREFILE   ICON_STR(FA_FILE_IMAGE_O, "󰈟", ICON_PICTURES)
+#define ICON_PICTURES      ICON_STR(MD_CAMERA_ALT, "󰉔", "🎨")
+#define ICON_PLAYLIST      ICON_STR(ICON_MUSICFILE, "󱍙", "")
+#define ICON_POWERPOINT    ICON_STR(FILE_POWERPOINT, "󰈧", "📊")
+#define ICON_PUBLIC        ICON_STR(FA_INBOX, "", "👀")
+#define ICON_PYTHON        ICON_STR(MFIZZ_PYTHON, "", "🐍")
+#define ICON_REACT         ICON_STR(FILE_JSX, "", ICON_JAVASCRIPT)
+#define ICON_RUBY          ICON_STR(MFIZZ_RUBY, "", "💎")
+#define ICON_RUST          ICON_STR(DEV_RUST, "", "")
+#define ICON_SASS          ICON_STR("", "", "")
+#define ICON_SCRIPT        ICON_STR(MFIZZ_SCRIPT, "", "📜")
+#define ICON_SUBTITLE      ICON_STR(FA_COMMENTS_O, "󰅺", "💬")
+#define ICON_TEMPLATES     ICON_STR(FA_PAPERCLIP, "󰗇", "📎")
+#define ICON_TEX           ICON_STR(FILE_TEX, "󰙩", ICON_DOCUMENT)
+#define ICON_VIDEOFILE     ICON_STR(FA_FILE_MOVIE_O, "󰈫", ICON_VIDEOS)
+#define ICON_VIDEOS        ICON_STR(FA_FILM, "󰈰", "🎞 ")
+#define ICON_VIM           ICON_STR(DEV_VIM, "", "")
+#define ICON_WORDDOC       ICON_STR(FILE_WORD, "󰈬", "📘")
 
 #define ICON_EXT_ASM       ICON_STR(FILE_NASM, "", "")
-#define ICON_EXT_BIN       ICON_STR(OCT_FILE_BINARY, "\uf471", "📓")
-#define ICON_EXT_COFFEE    ICON_STR(MFIZZ_COFFEE_BEAN, "\ue751", "")
-#define ICON_EXT_CSS       ICON_STR(MFIZZ_CSS3, "\ue749", "🦋")
-#define ICON_EXT_DEB       ICON_STR(MFIZZ_DEBIAN, "\ue77d", ICON_LINUX)
-#define ICON_EXT_DIFF      ICON_STR(FILE_DIFF, "\uf440", "📋")
-#define ICON_EXT_GO        ICON_STR(MFIZZ_GO, "\ufcd1", "")
-#define ICON_EXT_JSON      ICON_STR(ICON_JAVASCRIPT, "\ufb25", ICON_JAVASCRIPT)
-#define ICON_EXT_LUA       ICON_STR(FILE_LUA, "\ue620", "🌘")
-#define ICON_EXT_M         ICON_STR("", "\ufd1c", "📊")
-#define ICON_EXT_MAT       ICON_STR("", "\uf0ce", "")
-#define ICON_EXT_MD        ICON_STR(DEV_MARKDOWN, "\ue609", "📝")
-#define ICON_EXT_MSI       ICON_STR(FA_WINDOWS, "\uf871", "🪟")
-#define ICON_EXT_NIX       ICON_STR("", "\uf313", "")
-#define ICON_EXT_PATCH     ICON_STR(FILE_PATCH, "\uf440", "🩹")
-#define ICON_EXT_PHP       ICON_STR(MFIZZ_PHP, "\ue73d", "🌐")
-#define ICON_EXT_ROM       ICON_STR(FA_LOCK, "\uf795", "")
-#define ICON_EXT_RSS       ICON_STR(FA_RSS_SQUARE, "\uf143", "📡")
-#define ICON_EXT_RTF       ICON_STR(ICON_PDF, "\uf724", ICON_PDF)
-#define ICON_EXT_SCALA     ICON_STR(MFIZZ_SCALA, "\ue737", "")
-#define ICON_EXT_SLN       ICON_STR(DEV_VISUALSTUDIO, "\ue70c", "")
-#define ICON_EXT_TS        ICON_STR(FILE_TS, "\ue628", "")
+#define ICON_EXT_BIN       ICON_STR(OCT_FILE_BINARY, "", "📓")
+#define ICON_EXT_COFFEE    ICON_STR(MFIZZ_COFFEE_BEAN, "", "")
+#define ICON_EXT_CSS       ICON_STR(MFIZZ_CSS3, "", "🦋")
+#define ICON_EXT_DEB       ICON_STR(MFIZZ_DEBIAN, "", ICON_LINUX)
+#define ICON_EXT_DIFF      ICON_STR(FILE_DIFF, "", "📋")
+#define ICON_EXT_GO        ICON_STR(MFIZZ_GO, "󰟓", "")
+#define ICON_EXT_JSON      ICON_STR(ICON_JAVASCRIPT, "", ICON_JAVASCRIPT)
+#define ICON_EXT_LUA       ICON_STR(FILE_LUA, "", "🌘")
+#define ICON_EXT_M         ICON_STR("", "󰠞", "📊")
+#define ICON_EXT_MAT       ICON_STR("", "", "")
+#define ICON_EXT_MD        ICON_STR(DEV_MARKDOWN, "", "📝")
+#define ICON_EXT_MSI       ICON_STR(FA_WINDOWS, "󰍲", "🪟")
+#define ICON_EXT_NIX       ICON_STR("", "", "")
+#define ICON_EXT_PATCH     ICON_STR(FILE_PATCH, "", "🩹")
+#define ICON_EXT_PHP       ICON_STR(MFIZZ_PHP, "", "🌐")
+#define ICON_EXT_ROM       ICON_STR(FA_LOCK, "󰊖", "")
+#define ICON_EXT_RSS       ICON_STR(FA_RSS_SQUARE, "", "📡")
+#define ICON_EXT_RTF       ICON_STR(ICON_PDF, "󰈦", ICON_PDF)
+#define ICON_EXT_SCALA     ICON_STR(MFIZZ_SCALA, "", "")
+#define ICON_EXT_SLN       ICON_STR(DEV_VISUALSTUDIO, "", "")
+#define ICON_EXT_TS        ICON_STR(FILE_TS, "", "")
 
 
 /*
@@ -252,6 +253,7 @@ static const struct icon_pair icons_ext[] = { /* All entries are case-insensitiv
 	{"deb",        ICON_EXT_DEB,        COLOR_ARCHIVE},
 	{"diff",       ICON_EXT_DIFF,       0},
 	{"dll",        ICON_SCRIPT,         0},
+	{"djvu",       ICON_DJVU,           COLOR_DOCS},
 	{"doc",        ICON_WORDDOC,        COLOR_DOCUMENT},
 	{"docx",       ICON_WORDDOC,        COLOR_DOCUMENT},
 
@@ -286,7 +288,7 @@ static const struct icon_pair icons_ext[] = { /* All entries are case-insensitiv
 	{"h",          ICON_C,              COLOR_C},
 	{"hh",         ICON_CPLUSPLUS,      COLOR_C},
 	{"hpp",        ICON_CPLUSPLUS,      COLOR_C},
-	{"hs",         ICON_HASKELL,        COLOR_VIM},
+	{"hs",         ICON_HASKELL,        COLOR_ELIXIR},
 	{"htaccess",   ICON_CONFIGURE,      0},
 	{"htpasswd",   ICON_CONFIGURE,      0},
 	{"htm",        ICON_HTML,           0},
@@ -309,6 +311,7 @@ static const struct icon_pair icons_ext[] = { /* All entries are case-insensitiv
 	{"js",         ICON_JAVASCRIPT,     COLOR_JAVASCRIPT},
 	{"json",       ICON_EXT_JSON,       COLOR_JAVASCRIPT},
 	{"jsx",        ICON_REACT,          COLOR_REACT},
+	{"jxl",        ICON_PICTUREFILE,    COLOR_IMAGE},
 
 	/* K */
 	{"ksh",        ICON_SCRIPT,         COLOR_SHELL},
